==> huaweicloudsdkiec-3.1.137-py2.py3-none-any.whl: huaweicloudsdkiec/v1/model/attach_vip_bandwidth_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AttachVipBandwidthResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'vport': 'VirtualPortResponse'
    }

    attribute_map = {
        'vport': 'vport'
    }

    def __init__(self, vport=None):
        """AttachVipBandwidthResponse

        The model defined in huaweicloud sdk

        :param vport: 
        :type vport: :class:`huaweicloudsdkiec.v1.VirtualPortResponse`
        """
        
        super(AttachVipBandwidthResponse, self).__init__()

        self._vport = None
        self.discriminator = None

        if vport is not None:
            self.vport = vport

    @property
    def vport(self):
        """Gets the vport of this AttachVipBandwidthResponse.

        :return: The vport of this AttachVipBandwidthResponse.
        :rtype: :class:`huaweicloudsdkiec.v1.VirtualPortResponse`
        """
        return self._vport

    @vport.setter
    def vport(self, vport):
        """Sets the vport of this AttachVipBandwidthResponse.

        :param vport: The vport of this AttachVipBandwidthResponse.
        :type vport: :class:`huaweicloudsdkiec.v1.VirtualPortResponse`
        """
        self._vport = vport

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachVipBandwidthResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiec-3.1.145-py2.py3-none-any.whl: huaweicloudsdkiec/v1/model/attach_vip_bandwidth_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AttachVipBandwidthResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'vport': 'VirtualPortResponse'
    }

    attribute_map = {
        'vport': 'vport'
    }

    def __init__(self, vport=None):
        r"""AttachVipBandwidthResponse

        The model defined in huaweicloud sdk

        :param vport: 
        :type vport: :class:`huaweicloudsdkiec.v1.VirtualPortResponse`
        """
        
        super(AttachVipBandwidthResponse, self).__init__()

        self._vport = None
        self.discriminator = None

        if vport is not None:
            self.vport = vport

    @property
    def vport(self):
        r"""Gets the vport of this AttachVipBandwidthResponse.

        :return: The vport of this AttachVipBandwidthResponse.
        :rtype: :class:`huaweicloudsdkiec.v1.VirtualPortResponse`
        """
        return self._vport

    @vport.setter
    def vport(self, vport):
        r"""Sets the vport of this AttachVipBandwidthResponse.

        :param vport: The vport of this AttachVipBandwidthResponse.
        :type vport: :class:`huaweicloudsdkiec.v1.VirtualPortResponse`
        """
        self._vport = vport

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachVipBandwidthResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
